==> ejc-procurement-impl-3.0.0-20251203.122541-27-sources.jar: com/ejianc/business/procurement/plan/bean/AnswerDetailEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 计划答疑清单-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_answer_detail")
public class AnswerDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchase_item")
    private String purchaseItem; // 采购计划清单内容
    @TableField(value="purchase_plan_code")
    private String purchasePlanCode; // 采购计划来源单号
    @TableField(value="items")
    private String items; // 疑问事项
    @TableField(value="introducer_name")
    private String introducerName; // 提出人name
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="content")
    private String content; // 回复内容
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="reply_name")
    private String replyName; // 回复人名称
    @TableField(value="answer_id")
    private Long answerId; // 主表Id
    @TableField(value="purchase_plan_id")
    private Long purchasePlanId; // 采购计划来源id
    @TableField(value="introducer_id")
    private Long introducerId; // 提出人id
    @TableField(value="reply_id")
    private Long replyId; // 回复人id
    
    
    

    public String getPurchaseItem() {
        return purchaseItem;
    }

    public void setPurchaseItem(String purchaseItem) {
        this.purchaseItem = purchaseItem;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }
    public String getIntroducerName() {
        return introducerName;
    }

    public void setIntroducerName(String introducerName) {
        this.introducerName = introducerName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getReplyName() {
        return replyName;
    }

    public void setReplyName(String replyName) {
        this.replyName = replyName;
    }
    public Long getAnswerId() {
        return answerId;
    }

    public void setAnswerId(Long answerId) {
        this.answerId = answerId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    public Long getIntroducerId() {
        return introducerId;
    }

    public void setIntroducerId(Long introducerId) {
        this.introducerId = introducerId;
    }
    public Long getReplyId() {
        return replyId;
    }

    public void setReplyId(Long replyId) {
        this.replyId = replyId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251215.030943-114-sources.jar: com/ejianc/business/procurement/plan/bean/AnswerDetailEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 计划答疑清单-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_answer_detail")
public class AnswerDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchase_item")
    private String purchaseItem; // 采购计划清单内容
    @TableField(value="purchase_plan_code")
    private String purchasePlanCode; // 采购计划来源单号
    @TableField(value="items")
    private String items; // 疑问事项
    @TableField(value="introducer_name")
    private String introducerName; // 提出人name
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="content")
    private String content; // 回复内容
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="reply_name")
    private String replyName; // 回复人名称
    @TableField(value="answer_id")
    private Long answerId; // 主表Id
    @TableField(value="purchase_plan_id")
    private Long purchasePlanId; // 采购计划来源id
    @TableField(value="introducer_id")
    private Long introducerId; // 提出人id
    @TableField(value="reply_id")
    private Long replyId; // 回复人id
    @TableField(value="purchase_plan_detail_id")
    private Long purchasePlanDetailId; // 采购计划来源明细id


    public Long getPurchasePlanDetailId() {
        return purchasePlanDetailId;
    }

    public void setPurchasePlanDetailId(Long purchasePlanDetailId) {
        this.purchasePlanDetailId = purchasePlanDetailId;
    }

    public String getPurchaseItem() {
        return purchaseItem;
    }

    public void setPurchaseItem(String purchaseItem) {
        this.purchaseItem = purchaseItem;
    }
    public String getPurchasePlanCode() {
        return purchasePlanCode;
    }

    public void setPurchasePlanCode(String purchasePlanCode) {
        this.purchasePlanCode = purchasePlanCode;
    }
    public String getItems() {
        return items;
    }

    public void setItems(String items) {
        this.items = items;
    }
    public String getIntroducerName() {
        return introducerName;
    }

    public void setIntroducerName(String introducerName) {
        this.introducerName = introducerName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getReplyName() {
        return replyName;
    }

    public void setReplyName(String replyName) {
        this.replyName = replyName;
    }
    public Long getAnswerId() {
        return answerId;
    }

    public void setAnswerId(Long answerId) {
        this.answerId = answerId;
    }
    public Long getPurchasePlanId() {
        return purchasePlanId;
    }

    public void setPurchasePlanId(Long purchasePlanId) {
        this.purchasePlanId = purchasePlanId;
    }
    public Long getIntroducerId() {
        return introducerId;
    }

    public void setIntroducerId(Long introducerId) {
        this.introducerId = introducerId;
    }
    public Long getReplyId() {
        return replyId;
    }

    public void setReplyId(Long replyId) {
        this.replyId = replyId;
    }
    
}
